import { defineNuxtModule } from '@nuxt/kit';

const excludeList = [
  // Vue
  "vue",
  "@vue/runtime-core",
  "@vue/runtime-dom",
  "@vue/reactivity",
  "@vue/shared",
  "@vue/devtools-api",
  "vue-router",
  "vue-demi",
  // Nuxt Deps
  "pathe",
  "unenv",
  "klona",
  "devalue",
  "hookable",
  "unctx",
  "h3",
  "ofetch",
  "ufo",
  // Ecosystem
  "pinia",
  "@vueuse/core",
  "@vueuse/shared",
  "@vueuse/math"
];
const module = defineNuxtModule({
  meta: {
    name: "nuxt-better-optimize-deps",
    configKey: "betterOptimizeDeps"
  },
  defaults: {},
  setup(_options, nuxt) {
    nuxt.hook("vite:extendConfig", (config, { isServer }) => {
      if (isServer) {
        config.optimizeDeps ||= {};
        config.optimizeDeps.noDiscovery = true;
        return;
      }
      config.optimizeDeps ||= {};
      config.optimizeDeps.include = config.optimizeDeps.include?.filter((x) => !excludeList.includes(x)) || [];
      config.optimizeDeps.exclude = Array.from(/* @__PURE__ */ new Set([
        ...config.optimizeDeps.exclude || [],
        ...excludeList
      ]));
    });
  }
});

export { module as default };
